package de.uhh.informatik.vsis.gss.tools;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

/**
 * Virtueller Drucker mit Log-Funktion
 */
public class Drucker {
	protected final int nr;
	protected final List<String> log;
	protected final Random rand = new Random();

	/**
	 * Initialisiert den Drucker mit einer Druckernummer
	 * @param nr Druckernummer
	 */
	public Drucker(int nr) {
		this.nr = nr;
		log = new ArrayList<String>();
	}

	/**
	 * Druckt etwas (Druckdauer ist zufllig) und vermerkt Beginn und Ende im Log.
	 * @param str Zu druckender String
	 */
	public void drucke(String str) {
		log(str+": DRUCKBEGINN");
		int wait = (int)(rand.nextFloat()*1000);
		Tools.busyWait(wait);
		log(str+": Druckende");
	}

	/**
	 * Schreibt ein Ereignis in das interne Log
	 * @param str
	 */
	protected synchronized void log(String str) {
		log.add(str);
	}

	/**
	 * Gibt das komplette Log des Druckers direkt aus (Standardausgabe).
	 */
	public void printLog() {
		System.out.println(">> Druck-Log von Drucker "+nr);
		for (String entry : log) {
			System.out.println(entry);
		}
	}
}
